KakaoMapPluginPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- KakaoMapPluginPlatform
- Implementers
- Annotations
-
- @Deprecated('이 플러그인이 사용하지 않는 템플릿 잔재입니다. 다음 메이저 버전에서 제거됩니다.')
Constructors
- KakaoMapPluginPlatform()
- Constructs a KakaoMapPluginPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ KakaoMapPluginPlatform
-
The default instance of KakaoMapPluginPlatform to use.
getter/setter pair